==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_functions/gridresult/ObjectFactory.java <==

package net.datastream.schemas.mp_functions.gridresult;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_functions.gridresult package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_functions.gridresult
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link DATA }
     * 
     */
    public DATA createDATA() {
        return new DATA();
    }

    /**
     * Create an instance of {@link DATA.ROW }
     * 
     */
    public DATA.ROW createDATAROW() {
        return new DATA.ROW();
    }

    /**
     * Create an instance of {@link FIELDS }
     * 
     */
    public FIELDS createFIELDS() {
        return new FIELDS();
    }

    /**
     * Create an instance of {@link FIELD }
     * 
     */
    public FIELD createFIELD() {
        return new FIELD();
    }

    /**
     * Create an instance of {@link DATASPY }
     * 
     */
    public DATASPY createDATASPY() {
        return new DATASPY();
    }

    /**
     * Create an instance of {@link GRID_GRIDRESULT }
     * 
     */
    public GRID_GRIDRESULT createGRID_GRIDRESULT() {
        return new GRID_GRIDRESULT();
    }

    /**
     * Create an instance of {@link GRID }
     * 
     */
    public GRID createGRID() {
        return new GRID();
    }

    /**
     * Create an instance of {@link METADATA }
     * 
     */
    public METADATA createMETADATA() {
        return new METADATA();
    }

    /**
     * Create an instance of {@link DATA.R }
     * 
     */
    public DATA.R createDATAR() {
        return new DATA.R();
    }

    /**
     * Create an instance of {@link DATA.ROW.D }
     * 
     */
    public DATA.ROW.D createDATAROWD() {
        return new DATA.ROW.D();
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_functions/gridresult/ObjectFactory.java <==

package net.datastream.schemas.mp_functions.gridresult;

import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_functions.gridresult package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_functions.gridresult
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link DATA }
     * 
     * @return
     *     the new instance of {@link DATA }
     */
    public DATA createDATA() {
        return new DATA();
    }

    /**
     * Create an instance of {@link DATA.ROW }
     * 
     * @return
     *     the new instance of {@link DATA.ROW }
     */
    public DATA.ROW createDATAROW() {
        return new DATA.ROW();
    }

    /**
     * Create an instance of {@link METADATA }
     * 
     * @return
     *     the new instance of {@link METADATA }
     */
    public METADATA createMETADATA() {
        return new METADATA();
    }

    /**
     * Create an instance of {@link DATASPY }
     * 
     * @return
     *     the new instance of {@link DATASPY }
     */
    public DATASPY createDATASPY() {
        return new DATASPY();
    }

    /**
     * Create an instance of {@link FIELD }
     * 
     * @return
     *     the new instance of {@link FIELD }
     */
    public FIELD createFIELD() {
        return new FIELD();
    }

    /**
     * Create an instance of {@link FIELDS }
     * 
     * @return
     *     the new instance of {@link FIELDS }
     */
    public FIELDS createFIELDS() {
        return new FIELDS();
    }

    /**
     * Create an instance of {@link DATA.R }
     * 
     * @return
     *     the new instance of {@link DATA.R }
     */
    public DATA.R createDATAR() {
        return new DATA.R();
    }

    /**
     * Create an instance of {@link GRID }
     * 
     * @return
     *     the new instance of {@link GRID }
     */
    public GRID createGRID() {
        return new GRID();
    }

    /**
     * Create an instance of {@link GRID_GRIDRESULT }
     * 
     * @return
     *     the new instance of {@link GRID_GRIDRESULT }
     */
    public GRID_GRIDRESULT createGRID_GRIDRESULT() {
        return new GRID_GRIDRESULT();
    }

    /**
     * Create an instance of {@link DATA.ROW.D }
     * 
     * @return
     *     the new instance of {@link DATA.ROW.D }
     */
    public DATA.ROW.D createDATAROWD() {
        return new DATA.ROW.D();
    }

}
